@@ -59,7 +59,7 @@ pref("general.autoScroll", true);
 
 pref("general.warnOnAboutConfig", true);
 
-pref("general.useragent.extra.seamonkey", "SeaMonkey/1.1b");
+pref("general.useragent.extra.seamonkey", "SeaMonkey/1.1.12");
 //@line 63 "/home/robert/tinderbox/release-SeaMonkey-1.1/Linux_2.4.21-303-default_Clobber/mozilla/xpfe/bootstrap/browser-prefs.js"
 
 // 0 = blank, 1 = home (browser.startup.homepage), 2 = last
@@ -252,9 +252,9 @@ pref("dom.disable_window_flip",        true);
 // prevent JS from disabling or replacing context menus
 pref("dom.event.contextmenu.enabled",  true);
 
-//@line 265 "/home/robert/tinderbox/release-SeaMonkey-1.1/Linux_2.4.21-303-default_Clobber/mozilla/xpfe/bootstrap/browser-prefs.js"
-
 //@line 268 "/home/robert/tinderbox/release-SeaMonkey-1.1/Linux_2.4.21-303-default_Clobber/mozilla/xpfe/bootstrap/browser-prefs.js"
+
+//@line 271 "/home/robert/tinderbox/release-SeaMonkey-1.1/Linux_2.4.21-303-default_Clobber/mozilla/xpfe/bootstrap/browser-prefs.js"
 // For the download dialog
 pref("browser.download.progressDnldDialog.enable_launch_reveal_buttons", false);
 pref("browser.urlbar.clickSelectsAll", false);
